@@ -12,6 +12,10 @@
 
 #include "edgetree.h"
 #include "changestat.h"
+D_CHANGESTAT_FN(d_competitor_log_age);
+
+D_CHANGESTAT_FN(d_log_ages);
+
 D_CHANGESTAT_FN(d_edges_ageinterval);
 D_CHANGESTAT_FN(d_edges_ageinterval_mon);
 S_CHANGESTAT_FN(s_edges_ageinterval_mon);
